You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@qpid.apache.org by ro...@apache.org on 2012/11/21 13:20:47 UTC

svn commit: r1412076 - in /qpid/branches/java-broker-config-qpid-4390/qpid/java: broker/etc/ broker/src/main/java/org/apache/qpid/server/configuration/ broker/src/main/java/org/apache/qpid/server/configuration/startup/ broker/src/main/java/org/apache/q...

Author: robbie
Date: Wed Nov 21 12:20:45 2012
New Revision: 1412076

URL: http://svn.apache.org/viewvc?rev=1412076&view=rev
Log:
some tweaks on prior changes, plus remove more status-updates related config

Modified:
    qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/etc/config.xml
    qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/configuration/BrokerProperties.java
    qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/configuration/ServerConfiguration.java
    qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/configuration/startup/BrokerRecoverer.java
    qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/model/adapter/BrokerAdapter.java
    qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/registry/ApplicationRegistry.java
    qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/configuration/ServerConfigurationTest.java
    qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/actors/AMQPChannelActorTest.java
    qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/actors/AMQPConnectionActorTest.java
    qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/actors/BaseActorTestCase.java
    qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/actors/BaseConnectionActorTestCase.java
    qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/subjects/AbstractTestLogSubject.java
    qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/util/TestApplicationRegistry.java
    qpid/branches/java-broker-config-qpid-4390/qpid/java/systests/etc/config-systests-settings.xml
    qpid/branches/java-broker-config-qpid-4390/qpid/java/systests/src/main/java/org/apache/qpid/server/configuration/ServerConfigurationFileTest.java
    qpid/branches/java-broker-config-qpid-4390/qpid/java/systests/src/main/java/org/apache/qpid/server/logging/AbstractTestLogging.java
    qpid/branches/java-broker-config-qpid-4390/qpid/java/systests/src/main/java/org/apache/qpid/server/logging/VirtualHostLoggingTest.java

Modified: qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/etc/config.xml
URL: http://svn.apache.org/viewvc/qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/etc/config.xml?rev=1412076&r1=1412075&r2=1412076&view=diff
==============================================================================
--- qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/etc/config.xml (original)
+++ qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/etc/config.xml Wed Nov 21 12:20:45 2012
@@ -111,9 +111,6 @@
     <queue>
         <auto_register>true</auto_register>
     </queue>
-
-    <status-updates>ON</status-updates>
-
 </broker>
 
 

Modified: qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/configuration/BrokerProperties.java
URL: http://svn.apache.org/viewvc/qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/configuration/BrokerProperties.java?rev=1412076&r1=1412075&r2=1412076&view=diff
==============================================================================
--- qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/configuration/BrokerProperties.java (original)
+++ qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/configuration/BrokerProperties.java Wed Nov 21 12:20:45 2012
@@ -22,7 +22,7 @@ public class BrokerProperties
     public static final long DEFAULT_MINIMUM_ALERT_REPEAT_GAP = 30000l;
     public static final long DEFAULT_HOUSEKEEPING_PERIOD = 30000L;
 
-    public static final String PROPERTY_NO_STATUS_UPDATES = "qpid.no_status_updates";
+    public static final String PROPERTY_STATUS_UPDATES = "qpid.status_updates";
 
     private BrokerProperties()
     {

Modified: qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/configuration/ServerConfiguration.java
URL: http://svn.apache.org/viewvc/qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/configuration/ServerConfiguration.java?rev=1412076&r1=1412075&r2=1412076&view=diff
==============================================================================
--- qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/configuration/ServerConfiguration.java (original)
+++ qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/configuration/ServerConfiguration.java Wed Nov 21 12:20:45 2012
@@ -80,7 +80,6 @@ public class ServerConfiguration extends
     public static final String SECURITY_DEFAULT_AUTH_MANAGER = "security.default-auth-manager";
     public static final String SECURITY_PORT_MAPPINGS_PORT_MAPPING_AUTH_MANAGER = "security.port-mappings.port-mapping.auth-manager";
     public static final String SECURITY_PORT_MAPPINGS_PORT_MAPPING_PORT = "security.port-mappings.port-mapping.port";
-    public static final String STATUS_UPDATES = "status-updates";
     public static final String ADVANCED_LOCALE = "advanced.locale";
     public static final String CONNECTOR_AMQP10ENABLED = "connector.amqp10enabled";
     public static final String CONNECTOR_AMQP010ENABLED = "connector.amqp010enabled";
@@ -305,19 +304,6 @@ public class ServerConfiguration extends
     }
 
     /**
-     * Check the configuration file to see if status updates are enabled.
-     *
-     * @return true if status updates are enabled
-     */
-    public boolean getStatusUpdatesEnabled()
-    {
-        // Retrieve the setting from configuration but default to on.
-        String value = getStringValue(STATUS_UPDATES, DEFAULT_STATUS_UPDATES);
-
-        return value.equalsIgnoreCase("on");
-    }
-
-    /**
      * The currently defined {@see Locale} for this broker
      *
      * @return the configuration defined locale

Modified: qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/configuration/startup/BrokerRecoverer.java
URL: http://svn.apache.org/viewvc/qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/configuration/startup/BrokerRecoverer.java?rev=1412076&r1=1412075&r2=1412076&view=diff
==============================================================================
--- qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/configuration/startup/BrokerRecoverer.java (original)
+++ qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/configuration/startup/BrokerRecoverer.java Wed Nov 21 12:20:45 2012
@@ -66,7 +66,7 @@ public class BrokerRecoverer implements 
         int numberOfAuthenticationProviders = authenticationProviders.size();
         if (numberOfAuthenticationProviders == 0)
         {
-            throw new IllegalConfigurationException("No authentication provider was onfigured");
+            throw new IllegalConfigurationException("No authentication provider was configured");
         }
         else if (numberOfAuthenticationProviders == 1)
         {

Modified: qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/model/adapter/BrokerAdapter.java
URL: http://svn.apache.org/viewvc/qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/model/adapter/BrokerAdapter.java?rev=1412076&r1=1412075&r2=1412076&view=diff
==============================================================================
--- qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/model/adapter/BrokerAdapter.java (original)
+++ qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/model/adapter/BrokerAdapter.java Wed Nov 21 12:20:45 2012
@@ -454,11 +454,11 @@ public class BrokerAdapter extends Abstr
         {
             // TODO
         }
-        else if (DEFAULT_AUTHENTICATION_PROVIDER.equals(name) && _defaultAuthenticationProvider != null)
+        else if (DEFAULT_AUTHENTICATION_PROVIDER.equals(name))
         {
-            return _defaultAuthenticationProvider.getName();
+            return _defaultAuthenticationProvider == null ? null : _defaultAuthenticationProvider.getName();
         }
-        else if (DEFAULT_VIRTUAL_HOST.equals(name) && _defaultVirtualHost != null)
+        else if (DEFAULT_VIRTUAL_HOST.equals(name))
         {
             return _defaultVirtualHost;
         }

Modified: qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/registry/ApplicationRegistry.java
URL: http://svn.apache.org/viewvc/qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/registry/ApplicationRegistry.java?rev=1412076&r1=1412075&r2=1412076&view=diff
==============================================================================
--- qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/registry/ApplicationRegistry.java (original)
+++ qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/main/java/org/apache/qpid/server/registry/ApplicationRegistry.java Wed Nov 21 12:20:45 2012
@@ -201,7 +201,8 @@ public class ApplicationRegistry impleme
             BrokerMessages.reload();
 
             // Create the RootLogger to be used during broker operation
-            _rootMessageLogger = new Log4jMessageLogger(!Boolean.getBoolean(BrokerProperties.PROPERTY_NO_STATUS_UPDATES));
+            boolean statusUpdatesEnabled = Boolean.parseBoolean(System.getProperty(BrokerProperties.PROPERTY_STATUS_UPDATES, "true"));
+            _rootMessageLogger = new Log4jMessageLogger(statusUpdatesEnabled);
             initialiseStatisticsReporting();
 
             CurrentActor.setDefault(new BrokerActor(_rootMessageLogger));

Modified: qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/configuration/ServerConfigurationTest.java
URL: http://svn.apache.org/viewvc/qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/configuration/ServerConfigurationTest.java?rev=1412076&r1=1412075&r2=1412076&view=diff
==============================================================================
--- qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/configuration/ServerConfigurationTest.java (original)
+++ qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/configuration/ServerConfigurationTest.java Wed Nov 21 12:20:45 2012
@@ -129,26 +129,6 @@ public class ServerConfigurationTest ext
         assertEquals(23, _serverConfig.getFrameSize());
     }
 
-    public void testGetStatusEnabled() throws ConfigurationException
-    {
-        // Check default
-        _serverConfig.initialise();
-        assertEquals(ServerConfiguration.DEFAULT_STATUS_UPDATES.equalsIgnoreCase("on"),
-                     _serverConfig.getStatusUpdatesEnabled());
-
-        // Check disabling we set
-        _config.setProperty(ServerConfiguration.STATUS_UPDATES, "off");
-        _serverConfig = new ServerConfiguration(_config);
-        _serverConfig.initialise();
-        assertEquals(false, _serverConfig.getStatusUpdatesEnabled());
-
-        // Check invalid values don't cause error but result in disabled
-        _config.setProperty(ServerConfiguration.STATUS_UPDATES, "Yes Please");
-        _serverConfig = new ServerConfiguration(_config);
-        _serverConfig.initialise();
-        assertEquals(false, _serverConfig.getStatusUpdatesEnabled());
-
-    }
     public void testGetSynchedClocks() throws ConfigurationException
     {
         // Check default

Modified: qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/actors/AMQPChannelActorTest.java
URL: http://svn.apache.org/viewvc/qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/actors/AMQPChannelActorTest.java?rev=1412076&r1=1412075&r2=1412076&view=diff
==============================================================================
--- qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/actors/AMQPConnectionActorTest.java (original)
+++ qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/actors/AMQPConnectionActorTest.java Wed Nov 21 12:20:45 2012
@@ -21,6 +21,7 @@
 package org.apache.qpid.server.logging.actors;
 
 import org.apache.qpid.AMQException;
+import org.apache.qpid.server.configuration.BrokerProperties;
 import org.apache.qpid.server.logging.LogMessage;
 import org.apache.qpid.server.logging.LogSubject;
 
@@ -38,13 +39,6 @@ import java.util.List;
 public class AMQPConnectionActorTest extends BaseConnectionActorTestCase
 {
     @Override
-    public void configure()
-    {
-        // Prevent defaulting Logging to ON
-    }
-
-
-    @Override
     public void createBroker()
     {
         //Prevent auto-broker startup
@@ -60,8 +54,6 @@ public class AMQPConnectionActorTest ext
      */
     public void testConnection() throws Exception
     {
-        getConfigXml().setProperty("status-updates", "ON");
-
         super.createBroker();
 
         final String message = sendLogMessage();
@@ -90,7 +82,7 @@ public class AMQPConnectionActorTest ext
 
     public void testConnectionLoggingOff() throws Exception, AMQException
     {
-        getConfigXml().setProperty("status-updates", "OFF");
+        setTestSystemProperty(BrokerProperties.PROPERTY_STATUS_UPDATES, "false");
 
         // Start the broker now.
         super.createBroker();

Modified: qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/actors/BaseActorTestCase.java
URL: http://svn.apache.org/viewvc/qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/actors/BaseActorTestCase.java?rev=1412076&r1=1412075&r2=1412076&view=diff
==============================================================================
--- qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/actors/BaseActorTestCase.java (original)
+++ qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/actors/BaseActorTestCase.java Wed Nov 21 12:20:45 2012
@@ -20,7 +20,6 @@
  */
 package org.apache.qpid.server.logging.actors;
 
-import org.apache.qpid.server.configuration.ServerConfiguration;
 import org.apache.qpid.server.logging.LogActor;
 import org.apache.qpid.server.logging.LogMessage;
 import org.apache.qpid.server.logging.LogSubject;
@@ -35,23 +34,20 @@ public class BaseActorTestCase extends I
     protected RootMessageLogger _rootLogger;
 
     @Override
-    public void configure()
-    {
-        getConfigXml().setProperty(ServerConfiguration.STATUS_UPDATES, "on");
-    }
-
-    @Override
     public void createBroker() throws Exception
     {
         super.createBroker();
 
-        _rawLogger = new UnitTestMessageLogger(getRegistry().getConfiguration().getStatusUpdatesEnabled());
+        _rawLogger = new UnitTestMessageLogger(getRegistry().getRootMessageLogger().isEnabled());
         _rootLogger = _rawLogger;
     }
 
     public void tearDown() throws Exception
     {
-        _rawLogger.clearLogMessages();
+        if(_rawLogger != null)
+        {
+            _rawLogger.clearLogMessages();
+        }
 
         super.tearDown();
     }

Modified: qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/actors/BaseConnectionActorTestCase.java
URL: http://svn.apache.org/viewvc/qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/actors/BaseConnectionActorTestCase.java?rev=1412076&r1=1412075&r2=1412076&view=diff
==============================================================================
--- qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/actors/BaseConnectionActorTestCase.java (original)
+++ qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/actors/BaseConnectionActorTestCase.java Wed Nov 21 12:20:45 2012
@@ -22,7 +22,6 @@ package org.apache.qpid.server.logging.a
 
 public class BaseConnectionActorTestCase extends BaseActorTestCase
 {
-
     @Override
     public void createBroker() throws Exception
     {

Modified: qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/subjects/AbstractTestLogSubject.java
URL: http://svn.apache.org/viewvc/qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/subjects/AbstractTestLogSubject.java?rev=1412076&r1=1412075&r2=1412076&view=diff
==============================================================================
--- qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/subjects/AbstractTestLogSubject.java (original)
+++ qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/subjects/AbstractTestLogSubject.java Wed Nov 21 12:20:45 2012
@@ -258,13 +258,10 @@ public abstract class AbstractTestLogSub
     protected abstract void validateLogStatement(String message);
 
     /**
-     * Ensure that when status-updates are off this does not perform logging
-     *
-     * @throws ConfigurationException
+     * Ensure that when status updates are off this does not perform logging
      */
     public void testDisabled()
     {
-
         List<Object> logs = performLog(false);
 
         assertEquals("Log has incorrect message count", 0, logs.size());

Modified: qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/util/TestApplicationRegistry.java
URL: http://svn.apache.org/viewvc/qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/util/TestApplicationRegistry.java?rev=1412076&r1=1412075&r2=1412076&view=diff
==============================================================================
--- qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/util/TestApplicationRegistry.java (original)
+++ qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/util/TestApplicationRegistry.java Wed Nov 21 12:20:45 2012
@@ -49,7 +49,6 @@ public class TestApplicationRegistry ext
     @Override
     public void initialise() throws Exception
     {
-        System.setProperty(BrokerProperties.PROPERTY_NO_STATUS_UPDATES, "true");
         LoggingManagementFacade.configure("test-profiles/log4j-test.xml");
 
         super.initialise();
@@ -58,19 +57,6 @@ public class TestApplicationRegistry ext
         GenericActor.setDefaultMessageLogger(new NullRootMessageLogger());
     }
 
-    @Override
-    public void close()
-    {
-        try
-        {
-            super.close();
-        }
-        finally
-        {
-            System.clearProperty(BrokerProperties.PROPERTY_NO_STATUS_UPDATES);
-        }
-    }
-
     private static ConfigurationEntryStore createStore(Configuration config) throws ConfigurationException
     {
         File file;

Modified: qpid/branches/java-broker-config-qpid-4390/qpid/java/systests/etc/config-systests-settings.xml
URL: http://svn.apache.org/viewvc/qpid/branches/java-broker-config-qpid-4390/qpid/java/systests/etc/config-systests-settings.xml?rev=1412076&r1=1412075&r2=1412076&view=diff
==============================================================================
--- qpid/branches/java-broker-config-qpid-4390/qpid/java/systests/etc/config-systests-settings.xml (original)
+++ qpid/branches/java-broker-config-qpid-4390/qpid/java/systests/etc/config-systests-settings.xml Wed Nov 21 12:20:45 2012
@@ -96,7 +96,4 @@
     <queue>
         <auto_register>true</auto_register>
     </queue>
-
-    <status-updates>ON</status-updates>
-
 </broker>

Modified: qpid/branches/java-broker-config-qpid-4390/qpid/java/systests/src/main/java/org/apache/qpid/server/configuration/ServerConfigurationFileTest.java
URL: http://svn.apache.org/viewvc/qpid/branches/java-broker-config-qpid-4390/qpid/java/systests/src/main/java/org/apache/qpid/server/configuration/ServerConfigurationFileTest.java?rev=1412076&r1=1412075&r2=1412076&view=diff
==============================================================================
--- qpid/branches/java-broker-config-qpid-4390/qpid/java/systests/src/main/java/org/apache/qpid/server/configuration/ServerConfigurationFileTest.java (original)
+++ qpid/branches/java-broker-config-qpid-4390/qpid/java/systests/src/main/java/org/apache/qpid/server/configuration/ServerConfigurationFileTest.java Wed Nov 21 12:20:45 2012
@@ -62,11 +62,6 @@ public class ServerConfigurationFileTest
                       _serverConfig.getConfig().getProperty(property));
     }
 
-    public void testStatusUpdates() throws ConfigurationException
-    {
-        validatePropertyDefinedInFile(ServerConfiguration.STATUS_UPDATES);
-    }
-
     public void testLocale() throws ConfigurationException
     {
         validatePropertyDefinedInFile(ServerConfiguration.ADVANCED_LOCALE);

Modified: qpid/branches/java-broker-config-qpid-4390/qpid/java/systests/src/main/java/org/apache/qpid/server/logging/AbstractTestLogging.java
URL: http://svn.apache.org/viewvc/qpid/branches/java-broker-config-qpid-4390/qpid/java/systests/src/main/java/org/apache/qpid/server/logging/AbstractTestLogging.java?rev=1412076&r1=1412075&r2=1412076&view=diff
==============================================================================
--- qpid/branches/java-broker-config-qpid-4390/qpid/java/systests/src/main/java/org/apache/qpid/server/logging/AbstractTestLogging.java (original)
+++ qpid/branches/java-broker-config-qpid-4390/qpid/java/systests/src/main/java/org/apache/qpid/server/logging/AbstractTestLogging.java Wed Nov 21 12:20:45 2012
@@ -58,33 +58,6 @@ public class AbstractTestLogging extends
         _monitor = new LogMonitor(_outputFile);
     }
 
-    // XXX remove reference on ServerConfiguration
-    protected ServerConfiguration getServerConfig() throws ConfigurationException
-    {
-        ServerConfiguration _serverConfiguration;
-        if (isExternalBroker())
-        {
-            _serverConfiguration = new ServerConfiguration(_configFile)
-            {
-                @Override
-                public void initialise() throws ConfigurationException
-                {
-                    //Overriding initialise to only setup the vhosts and not
-                    //perform the ConfigurationPlugin setup, removing need for
-                    //an ApplicationRegistry to be loaded.
-                    setupVirtualHosts(getConfig());
-                }
-            };
-            _serverConfiguration.initialise();
-        }
-        else
-        {
-            _serverConfiguration = ApplicationRegistry.getInstance().getConfiguration();
-        }
-
-        return _serverConfiguration;
-    }
-
     protected void setLogMessagePrefix()
     {
         //set the message prefix to facilitate scraping from the munged test output.

Modified: qpid/branches/java-broker-config-qpid-4390/qpid/java/systests/src/main/java/org/apache/qpid/server/logging/VirtualHostLoggingTest.java
URL: http://svn.apache.org/viewvc/qpid/branches/java-broker-config-qpid-4390/qpid/java/systests/src/main/java/org/apache/qpid/server/logging/VirtualHostLoggingTest.java?rev=1412076&r1=1412075&r2=1412076&view=diff
==============================================================================
--- qpid/branches/java-broker-config-qpid-4390/qpid/java/systests/src/main/java/org/apache/qpid/server/logging/VirtualHostLoggingTest.java (original)
+++ qpid/branches/java-broker-config-qpid-4390/qpid/java/systests/src/main/java/org/apache/qpid/server/logging/VirtualHostLoggingTest.java Wed Nov 21 12:20:45 2012
@@ -68,7 +68,7 @@ public class VirtualHostLoggingTest exte
         
         try
         {
-            List<String> vhosts = Arrays.asList(getServerConfig().getVirtualHostsNames());
+            List<String> vhosts = Arrays.asList("test");
 
             assertEquals("Each vhost did not create a store.", vhosts.size(), results.size());
 



---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@qpid.apache.org
For additional commands, e-mail: commits-help@qpid.apache.org
--- qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/actors/AMQPChannelActorTest.java (original)
+++ qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/actors/AMQPChannelActorTest.java Wed Nov 21 12:20:45 2012
@@ -20,9 +20,7 @@
  */
 package org.apache.qpid.server.logging.actors;
 
-import org.apache.commons.configuration.ConfigurationException;
-
-import org.apache.qpid.AMQException;
+import org.apache.qpid.server.configuration.BrokerProperties;
 
 import java.util.List;
 
@@ -37,14 +35,6 @@ import java.util.List;
  */
 public class AMQPChannelActorTest extends BaseConnectionActorTestCase
 {
-
-    @Override
-    public void configure()
-    {
-        // Prevent defaulting Logging to ON
-    }
-    
-
     @Override
     public void createBroker() throws Exception
     {
@@ -68,8 +58,6 @@ public class AMQPChannelActorTest extend
      */
     public void testChannel() throws Exception
     {
-        getConfigXml().setProperty("status-updates", "ON");
-
         startBrokerNow();
 
         final String message = sendTestLogMessage(_amqpActor);
@@ -95,18 +83,15 @@ public class AMQPChannelActorTest extend
         // Verify that the logged message contains the 'ch:1' marker
         assertTrue("Message was not logged as part of channel 1" + logs.get(0),
                    logs.get(0).toString().contains("/ch:1"));
-
     }
 
     /**
      * Test that if logging is configured to be off in the configuration that
      * no logging is presented
-     * @throws ConfigurationException
-     * @throws AMQException
      */
-    public void testChannelLoggingOFF() throws Exception, AMQException
+    public void testChannelLoggingOFF() throws Exception
     {
-        getConfigXml().setProperty("status-updates", "OFF");
+        setTestSystemProperty(BrokerProperties.PROPERTY_STATUS_UPDATES, "false");
 
         // Start the broker now.
         startBrokerNow();
@@ -116,107 +101,5 @@ public class AMQPChannelActorTest extend
         List<Object> logs = _rawLogger.getLogMessages();
 
         assertEquals("Message log size not as expected.", 0, logs.size());
-
-    }
-
-      /**
-     * Test that if logging is configured to be off in the configuration that
-     * no logging is presented
-     * @throws ConfigurationException
-     * @throws AMQException
-     */
-    public void testChannelLoggingOfF() throws Exception, AMQException
-    {
-        getConfigXml().setProperty("status-updates", "OfF");
-
-        startBrokerNow();
-
-        sendTestLogMessage(_amqpActor);
-
-        List<Object> logs = _rawLogger.getLogMessages();
-
-        assertEquals("Message log size not as expected.", 0, logs.size());
-
     }
-
-    /**
-     * Test that if logging is configured to be off in the configuration that
-     * no logging is presented
-     * @throws ConfigurationException
-     * @throws AMQException
-     */
-    public void testChannelLoggingOff() throws Exception, AMQException
-    {
-        getConfigXml().setProperty("status-updates", "Off");
-
-        startBrokerNow();
-
-        sendTestLogMessage(_amqpActor);
-
-        List<Object> logs = _rawLogger.getLogMessages();
-
-        assertEquals("Message log size not as expected.", 0, logs.size());
-
-    }
-
-    /**
-     * Test that if logging is configured to be off in the configuration that
-     * no logging is presented
-     * @throws ConfigurationException
-     * @throws AMQException
-     */
-    public void testChannelLoggingofF() throws Exception, AMQException
-    {
-        getConfigXml().setProperty("status-updates", "ofF");
-
-        startBrokerNow();
-
-        sendTestLogMessage(_amqpActor);
-
-        List<Object> logs = _rawLogger.getLogMessages();
-
-        assertEquals("Message log size not as expected.", 0, logs.size());
-
-    }
-
-    /**
-     * Test that if logging is configured to be off in the configuration that
-     * no logging is presented
-     * @throws ConfigurationException
-     * @throws AMQException
-     */
-    public void testChannelLoggingoff() throws Exception, AMQException
-    {
-        getConfigXml().setProperty("status-updates", "off");
-
-        startBrokerNow();
-
-        sendTestLogMessage(_amqpActor);
-
-        List<Object> logs = _rawLogger.getLogMessages();
-
-        assertEquals("Message log size not as expected.", 0, logs.size());
-
-    }
-
-    /**
-     * Test that if logging is configured to be off in the configuration that
-     * no logging is presented
-     * @throws ConfigurationException
-     * @throws AMQException
-     */
-    public void testChannelLoggingoFf() throws Exception, AMQException
-    {        
-        getConfigXml().setProperty("status-updates", "oFf");
-
-        startBrokerNow();
-
-        sendTestLogMessage(_amqpActor);
-
-        List<Object> logs = _rawLogger.getLogMessages();
-
-        assertEquals("Message log size not as expected.", 0, logs.size());
-
-    }
-
 }
@@ -95,18 +83,15 @@ public class AMQPChannelActorTest extend
 
     /**
-     * Test that if logging is configured to be off in the configuration that
+     * Test that if logging is configured to be off via system property that
      * no logging is presented

Modified: qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/actors/AMQPConnectionActorTest.java
URL: http://svn.apache.org/viewvc/qpid/branches/java-broker-config-qpid-4390/qpid/java/broker/src/test/java/org/apache/qpid/server/logging/actors/AMQPConnectionActorTest.java?rev=1412076&r1=1412075&r2=1412076&view=diff
==============================================================================